import {
  Controller,
  Post,
  Body,
  Req,
  UseInterceptors,
  UseFilters,
} from '@nestjs/common';
import { AuthService } from './auth.service';
import { LoginDto } from './dto/req/login.dto';
import { IRequest } from '@/interface';
import { LoginRecordDto } from './dto/loginRecord.dto';
import { ApiResponseInterceptor } from '@/common/interceptor/api.response.interceptor';
import { ApiExceptionsFilter } from '@/common/filter/api.exception.filter';
import { RegisterDto } from './dto/req/register.dto';
import { Auth } from '@/common/decorators/auth.decorator';

@Controller('auth')
@UseInterceptors(ApiResponseInterceptor)
@UseFilters(ApiExceptionsFilter)
export class AuthController {
  constructor(private readonly authService: AuthService) {}

  // 登录接口
  @Post('login')
  async login(@Body() loginDto: LoginDto, @Req() req: IRequest) {
    const record: LoginRecordDto = {
      userId: null,
      ip: req.ip,
      lastActiveTime: Math.floor(Date.now() / 1000),
      level: 0,
      platform: 9,
      userAgent: req.userAgent,
    };

    // 调用服务层登录方法
    return await this.authService.login(loginDto, record);
  }

  // 注册接口
  @Post('register')
  async register(@Body() registerDto: RegisterDto) {
    return await this.authService.register(registerDto);
  }

  // 退出登录接口
  @Auth()
  @Post('logout')
  async logout(@Req() req: IRequest) {
    return await this.authService.logout(req.token, req.decodedToken.exp);
  }
}
